data: Lymphoma Microarray Data

d5:lymphomaR Documentation

Lymphoma Microarray Data

Description

This is one of the microarray data sets used to demonstrate BCBCSF in the reference article. Information about this data set can be found from the reference.

Usage

    data(lymphoma)

Value

lymph.X

a matrix of gene expression data for p = 4026 genes on n = 62 cases in G=3 classes

lymph.y

a vector of class labels coded by 1,2,3.


BCBCSF documentation built on March 30, 2026, 5:07 p.m.

Related to data in BCBCSF...